==> simutrans_102.0.orig.tar.gz: simutrans-102.0/scrolltext.h <==
/* prissi: first part is left, second part right side */

"","",
"","",
"","",
"","",
"","",
"","",
"","",
"Programming:","",
"","",
" Hansjrg Malthaner","",
"","",
"","",
"Additional Programming:","",
"","",
" Volker Meyer","big patches",
" Hendrik Siegeln","patches",
" Niels Roest","GUI",
" Markus Weber","GUI changes",
" Markus Pristovsek","current head",
" Owen Rudge","MIDI, patches",
" Tomas Kubes","misc. patches",
" Rainer Bertram","misc. patches",
" Andreas Rver","misc. patches",
" Tilman Raatz","misc. patches",
" Pasi Ruhanen","BeOS, SDL",
" Mat Hounsell","GUI",
" Christoph Mallon","Makefile, patches",
" Kieron Green","skinned grounds",
" z9999","misc. patches",
"","",
"","",
"Game Design Assistance:","",
"","",
" Peter J. Dobrovka","",
" Tomas Kubes","pak128",
" Frank Penz","pak.german",
" Yoshihiro Shishido","pak.japan128",
"","",
"","",
"Graphics:","",
"","",
" Flor Wauters","",
" Georg 'MHz' Moers","",
" Hansjrg Malthaner","",
" James Starr","",
" Manfred Tomaschitz","",
" Oskari 'TPI' Saarekas","",
" Patrick Nesbitt","",
" Peter J. Dobrovka","",
" Rick 'Trikky' McGreal","",
" Sergiu Croitor","",
" Seth C. Triggs","",
" Tomas Kubes","",
" Guillermo 'raven' Mateo","",
" Alexander Brose","",
"","",
"and many more","",
"","",
"","",
"Translation:","",
"","",
" Alberto Beccaria","Italian",
" George Dragon","Hungarian",
" Hansjrg Malthaner","German",
" Marcal Guardiola","Spanish",
" Niels Roest","Dutch",
" Pasi Ruhanen","Finnish",
" Rmi Denis-Courmont","French",
" Ferencz Szekely","Hungary and Romanian",
" Alex Revo","Russian",
" Roman Schwrer","",
"","",
"and many more","",
"","",
"","",
"Additional Thanks go to:","",
"","",
" Bernhard Mecl","",
"","the very first Simutrans beta tester",
" Bram Schoenmakers","",
"","the most critical tester",
" Gerhard Hafner","",
"","for providing tons of railway information",
" Marcus Haupt","",
"","for lots of help with tricky problems",
" Vern Moorhouse", "",
"","for some valuable technical hints",
" Isaac Eiland-Hall","",
"","hosting simutrans.com",
" Dirk Burkholz","",
"","hosting wiki and german Forum",
"","",
"", "",
" And many thanks to all testers and","",
" players, and all who supported the","",
" project!","",
"","",
"","",
"","",
"","",
"","",
"","",
"","",
0

==> simutrans_110.0.1.orig.tar.gz: simutrans-110.0.1/scrolltext.h <==
/* prissi: first part is left, second part right side */

"","",
"","",
"","",
"","",
"","",
"","",
"","",
"Programming:","",
"","",
" Hansjrg Malthaner","",
"","",
"","",
"Current Team:","",
" Markus Pristovsek","current head",
" Daniel Wachsmuth", "developer",
" Christoph Mallon","Makefile, patches",
" Knightly", "developer",
"","",
"","",
"Additional Programming:","",
"","",
" Volker Meyer","big patches",
" Hendrik Siegeln","ex developer",
" Niels Roest","GUI",
" Markus Weber","GUI changes",
" Owen Rudge","MIDI, patches",
" Tomas Kubes","patches",
" Rainer Bertram","patches",
" Andreas Rver","patches",
" Tilman Raatz","patches",
" Pasi Ruhanen","BeOS, SDL",
" Mat Hounsell","GUI",
" Kieron Green","skinned grounds",
" z9999","patches",
" Gerd Wachsmuth", "patches",
"","",
"","",
"Game Design Assistance:","",
"","",
" Peter J. Dobrovka","",
" Tomas Kubes","pak128",
" Vladimir Slavik", "pak128",
" Frank Penz","pak.german",
" Yoshihiro Shishido","pak.japan128",
" Sven Osada","pak96.comic",
"","",
"Graphics:","",
"","",
" Flor Wauters","",
" Georg 'MHz' Moers","",
" Hansjrg Malthaner","",
" James Starr","",
" Manfred Tomaschitz","",
" Oskari 'TPI' Saarekas","",
" Patrick Nesbitt","",
" Peter J. Dobrovka","",
" Rick 'Trikky' McGreal","",
" Sergiu Croitor","",
" Seth C. Triggs","",
" Tomas Kubes","",
" Guillermo 'raven' Mateo","",
" Alexander Brose","",
"","",
"and many more","",
"","",
"","",
"Translation:","",
"","",
" Alberto Beccaria","Italian",
" George Dragon","Hungarian",
" Hansjrg Malthaner","German",
" Marcal Guardiola","Spanish",
" Niels Roest","Dutch",
" Pasi Ruhanen","Finnish",
" Rmi Denis-Courmont","French",
" Ferencz Szekely","Hungary & Romanian",
" Alex Revo","Russian",
" Roman Schwrer","French & German",
" Yannis Kaskamanid", "Greek",
" Igor Eliezer", "Portuguese",
" Joan-Josep Bargues", "Catalan",
" Susanna Bjrverud", "Swedish",
" Xavier Paz", "Spanish",
" Wim Vreeswijk", "Dutch",
" Paul Color", "Swedish",
" Ignas Brasiskis", "Lithuanian",
"","",
"and many more","",
"","",
"","",
"Additional Thanks go to:","",
"","",
" Bernhard Mecl","",
"","the very first Simutrans beta tester",
" Bram Schoenmakers","",
"","the most critical tester",
" Gerhard Hafner","",
"","for providing tons of railway information",
" Marcus Haupt","",
"","for lots of help with tricky problems",
" Vern Moorhouse", "",
"","for some valuable technical hints",
" Isaac Eiland-Hall","",
"","hosting simutrans.com",
" Dirk Burkholz","",
"","hosting german Forum",
" Frank Penz", "",
"", "Simutranslator, Wiki, and more",
" Christoph Mallon", "",
"", "hosting the SVN",
" werniman", "",
"", "nightly builds",
"","",
"", "",
" And many thanks to all testers and","",
" players, and all who supported the","",
" project!","",
"","",
"","",
"","",
"","",
"","",
"","",
"","",
0
